@@ -9,7 +9,7 @@ package Rex::Group;
 use strict;
 use warnings;
 
-our $VERSION = '1.12.2.2'; # TRIAL VERSION
+our $VERSION = '1.12.2.3'; # TRIAL VERSION
 
 use Rex::Logger;
 
@@ -17,7 +17,7 @@ use attributes;
 use Rex::Group::Entry::Server;
 
 use vars qw(%groups);
-use List::MoreUtils qw(uniq);
+use List::MoreUtils 0.416 qw(uniq);
 use Data::Dumper;
 
 sub new {
