@@ -9,7 +9,7 @@ package Rex::Group::Entry::Server;
 use strict;
 use warnings;
 
-our $VERSION = '1.12.2.2'; # TRIAL VERSION
+our $VERSION = '1.12.2.3'; # TRIAL VERSION
 
 use Rex::Logger;
 use Rex::Helper::System;
@@ -19,7 +19,7 @@ use Data::Dumper;
 use Sort::Naturally;
 use Symbol;
 
-use List::MoreUtils qw(uniq);
+use List::MoreUtils 0.416 qw(uniq);
 
 use overload
   'eq'  => sub { shift->is_eq(@_); },
